custom_share library
A Flutter plugin for sharing content to social media and system share UI on Android and iOS platforms.
This file provides a simple interface to share text and a single file using
native platform share dialogs, such as ACTION_SEND on Android and
UIActivityViewController on iOS.
Example:
import 'package:custom_share/custom_share.dart';
void main() async {
final result = await CustomShare.shareText(text: 'Hello, world!');
print(result);
final fileResult = await CustomShare.shareFile(filePath: 'path/to/image.png');
print(fileResult);
}
Classes
- A class that provides static methods to share content on Android and iOS.